=head1 NAME

DynGig::CLI - A collection of CLI modules

=cut
package DynGig::Util;

=head1 VERSION

Version 0.02

=cut
our $VERSION = '0.02';

=head1 MODULES

=head2 DynGig::CLI::Schedule::Make

Making a schedule config from polices

=head2 DynGig::CLI::Schedule::Period

Scheduling tool

=head2 DynGig::CLI::OpsDB

CLI for a simple operations database

=head2 DynGig::CLI::Service

CLI for daemontools service

=head2 DynGig::CLI::Range

CLI for DynGig::Range::String ( expand/serial/count )

=head2 DynGig::CLI::Mulplex::CMD 

CLI for DynGig::Multiplex::CMD

=head2 DynGig::CLI::Mulplex::TCP 

CLI for DynGig::Multiplex::TCP

=head2 DynGig::CLI::Sequence::CTRL 

CLI for sequence control.

=head2 DynGig::CLI::Sequence::Run 

CLI for sequence run.

=head2 DynGig::CLI::Watcher::Exclude 

CLI for watcher exclude.

=head2 DynGig::CLI::Watcher::Run 

CLI for watcher run.

=head2 DynGig::CLI::RCED 

CLI for RCE Server

=head2 DynGig::CLI::Cluster::Client

CLI for DynGig::Range::Cluster ( expand/serial/count )

=head2 DynGig::CLI::Cluster::Cache

CLI for cluster cache

=head2 DynGig::CLI::Cluster::Server

CLI for cluster server

=cut

=head1 AUTHOR

Kan Liu

=head1 COPYRIGHT and LICENSE

Copyright (c) 2010. Kan Liu

This program is free software; you may redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;

__END__

